@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 use App::FatPacker;
 use Config;
-use Cwd 'cwd';
+use Cwd 'abs_path';
 use Distribution::Metadata;
 use File::Basename 'basename';
 use File::Find 'find';
@@ -14,7 +14,7 @@ use Getopt::Long qw(:config no_auto_abbrev no_ignore_case);
 use Perl::Strip;
 use Pod::Usage 'pod2usage';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our $IGNORE_FILE = [
     qr/\.pod$/,
@@ -128,12 +128,15 @@ sub fatpack_file {
 sub load_main_script {
     my ($self, $file) = @_;
     open my $fh, "<", $file or die "Cannot open '$file': $!\n";
-    my ($shebang, $script) = ( scalar(<$fh>), join "", <$fh> );
-    if (index($shebang, '#!') != 0) {
-        $shebang = "";
-        $script  = $shebang . $script;
+    my @lines = <$fh>;
+    my @shebang;
+    if (@lines && index($lines[0], '#!') == 0) {
+        while (1) {
+            push @shebang, shift @lines;
+            last if $shebang[-1] =~ m{^\#\!.*perl};
+        }
     }
-    ($shebang, $script);
+    ((join "", @shebang), (join "", @lines));
 }
 
 sub load_file {
@@ -151,14 +154,22 @@ sub load_file {
 
 sub collect_files {
     my ($self, $dir, $files) = @_;
+
+    # When $dir is not an archlib,
+    # and we are about to search $dir/archlib, skip it!
+    # because $dir/archlib itself will be searched another time.
+    my $skip_dir = catdir($dir, $Config{archname});
+    $skip_dir = qr/\Q$skip_dir\E/;
+
     find sub {
         return unless -f $_;
         for my $ignore (@$IGNORE_FILE) {
             $_ =~ $ignore and return;
         }
-        if ($File::Find::name =~ m!$dir/$Config{archname}!) {
+        if ($File::Find::name =~ $skip_dir) {
             return;
         }
+
         my $relative = File::Spec::Unix->abs2rel($File::Find::name, $dir);
         for my $exclude (@{$self->{exclude}}) {
             if ($File::Find::name eq $exclude) {
@@ -176,9 +187,8 @@ sub collect_files {
 
 sub build_dir {
     my ($self, $dir_string) = @_;
-    my $cwd = cwd;
     my @dir;
-    for my $d (grep -d, map { catdir($cwd, $_) } split /,/, $dir_string) {
+    for my $d (map { abs_path $_ } grep -d, split /,/, $dir_string) {
         my $try = catdir($d, "lib/perl5");
         if (-d $try) {
             push @dir, $try, catdir($try, $Config{archname});
